zmodem library

Classes

ZCrcErrorEvent
A data subpacket with an invalid CRC was received.
ZFileAcceptedEvent
The other side has accepted a file we just offered.
ZFileDataEvent
A chunk of data of the file currently being received.
ZFileEndEvent
The file we're currently receiving has been completely transferred.
ZFileOfferedEvent
The other side has offered a file for transfer.
ZFileSkippedEvent
The other side has rejected a file we just offered.
ZModemCore
Contains the state of a ZModem session.
ZModemEvent
ZModemFileInfo
ZReadyToSendEvent
The other side is ready to receive a file.
ZSessionCancelledEvent
The remote side has sent a cancel sequence (5 × CAN). The session is reset.
ZSessionFinishedEvent
The event fired when the ZModem session is fully closed.
ZTimeoutEvent
A blocking state timed out (e.g., waiting for content).

Enums

ZModemState

Typedefs

ZModemTextHandler = void Function(int char)
ZModemTraceHandler = void Function(String message)

Exceptions / Errors

ZModemException